GPT Code Scrapper
=================

The simple code that scraps the code for the further analysis by the ChatGPT.

- Github: https://github.com/danpeczek/gpt-scrapper

Installation
============

.. code-block:: bash

    $ pip install gpt-scrapper

Usage
=====

.. code-block:: bash

    Usage: gpt-scrapper [OPTIONS] PATH
    Options:
      -e, --extensions TEXT  Extensions to search for
      --help                 Show this message and exit.

The result scrapped code should be available in the `output.txt` file.

License
=======
`MIT LICENSE <https://github.com/danpeczek/gpt-scrapper/blob/main/LICENSE>`__
